@@ -1,5 +1,12 @@
 # -*- coding:utf-8 -*-
 
+from django.conf import settings
+
+# Here you can override any settings from coop default settings files
+# See :
+# - coop/default_project_settings.py
+# - coop/db_settings.py
+
 SITE_AUTHOR = 'Organisme'
 SITE_TITLE = 'Demo Django-coop'
 DEFAULT_URI_DOMAIN = '{{ domain }}'
@@ -15,12 +22,9 @@ MANAGERS = ADMINS
 SEND_BROKEN_LINK_EMAILS = True
 INTERNAL_IPS = ('127.0.0.1', '92.243.30.98')
 
-
 SUBHUB_MAINTENANCE_AUTO = False    # set this value to True to automatically syncronize with agregator
-PES_HOST = 'pes.domain.com'         
-THESS_HOST = 'thess.domain.com'
-
-from django.conf import settings
+PES_HOST = 'pes.domain.com'
+THESAURUS_HOST = 'thess.domain.com'
 
 INSTALLED_APPS = settings.INSTALLED_APPS + [
     # select your coop components
@@ -30,6 +34,8 @@ INSTALLED_APPS = settings.INSTALLED_APPS + [
     'coop.mailing',
     'coop.exchange',
     #'coop.webid',
-    'coop_geo',
     'coop_local',
+
+    # coop optional modules
+    'coop_geo',  # est obligatoirement placé APRES coop_local
 ]
\ No newline at end of file
